[Vtigercrm-commits] [vtiger-commits] r7488 - /vtigercrm/trunk/include/nusoap/nusoap.php

vtigercrm-commits at vtiger.fosslabs.com vtigercrm-commits at vtiger.fosslabs.com
Sat Jun 24 15:45:46 EDT 2006


Author: mmbrich
Date: Sat Jun 24 13:45:44 2006
New Revision: 7488

Log:
in php5 soapclient is already declared, changed nusoap soapclient class to soapclient2

Modified:
    vtigercrm/trunk/include/nusoap/nusoap.php

Modified: vtigercrm/trunk/include/nusoap/nusoap.php
==============================================================================
--- vtigercrm/trunk/include/nusoap/nusoap.php (original)
+++ vtigercrm/trunk/include/nusoap/nusoap.php Sat Jun 24 13:45:44 2006
@@ -35,7 +35,7 @@
 /* load classes
 
 // necessary classes
-require_once('class.soapclient.php');
+require_once('class.soapclient2.php');
 require_once('class.soap_val.php');
 require_once('class.soap_parser.php');
 require_once('class.soap_fault.php');
@@ -2824,7 +2824,7 @@
 			($http_status >= 400 && $http_status <= 417) ||
 			($http_status >= 501 && $http_status <= 505)
 		   ) {
-			$this->setError("Unsupported HTTP response status $http_status $http_reason (soapclient->response has contents of the response)");
+			$this->setError("Unsupported HTTP response status $http_status $http_reason (soapclient2->response has contents of the response)");
 			return false;
 		}
 
@@ -6387,24 +6387,24 @@
 
 /**
 *
 * soapclient higher level class for easy usage.
 *
 * usage:
 *
 * // instantiate client with server info
-* $soapclient = new soapclient( string path [ ,boolean wsdl] );
+* $soapclient2 = new soapclient2( string path [ ,boolean wsdl] );
 *
 * // call method, get results
-* echo $soapclient->call( string methodname [ ,array parameters] );
+* echo $soapclient2->call( string methodname [ ,array parameters] );
 *
 * // bye bye client
-* unset($soapclient);
+* unset($soapclient2);
 *
 * @author   Dietrich Ayala <dietrich at ganx4.com>
 * @version  $Id: nusoap.php,v 1.94 2005/08/04 01:27:42 snichol Exp $
 * @access   public
 */
-class soapclient extends nusoap_base  {
+class soapclient2 extends nusoap_base  {
 
 	var $username = '';
 	var $password = '';
@@ -6471,7 +6471,7 @@
 	* @param	integer $response_timeout set the response timeout
 	* @access   public
 	*/
-	function soapclient($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
+	function soapclient2($endpoint,$wsdl = false,$proxyhost = false,$proxyport = false,$proxyusername = false, $proxypassword = false, $timeout = 0, $response_timeout = 30){
 		parent::nusoap_base();
 		$this->endpoint = $endpoint;
 		$this->proxyhost = $proxyhost;
@@ -7051,7 +7051,7 @@
 				unset($paramCommentStr);
 			}
 		}
-		$evalStr = 'class soap_proxy_'.$r.' extends soapclient {
+		$evalStr = 'class soap_proxy_'.$r.' extends soapclient2 {
 	'.$evalStr.'
 }';
 		return $evalStr;
@@ -6387,24 +6387,24 @@
 /**
 *
-* soapclient higher level class for easy usage.
+* soapclient2 higher level class for easy usage.
 *
 * usage:





More information about the vtigercrm-commits mailing list